	/**
	*  Grid overlay for createjs. Ex: getGrid(), getGrid(null,null, 50, null, null, "#ff0")
	*  @param {String} origin Tick lines drawn from [center | canvas | default | undefined | null] Default = canvas
	*  @param {Number} hGridLineSpace Horizontal space between grid lines [number | undefined | null]. Default = 25
	*  @param {Number} vGridLineSpace Vertical space between grid lines [number | undefined | null]. Default = 25
	*  @param {String} lineColorHex Hex color for the grid lines [string | undefined | null]. Default = #8FD8D8
	*  @param {String} groupLineColorHex Hex color for the grid lines [string | undefined | null]. Default = #ff00ff
	*  @param {String} centerLineColorHex Hex color for the grid lines [string | undefined | null]. Default = #F5F5F5
	*  @return {Shape} A createjs.Shape() object for 0,0 on canvas.
	*/
	function getGrid( origin, hGridLineSpace, vGridLineSpace, lineColorHex, groupLineColorHex, centerLineColorHex )
	{
		// Sanitize arguments and set defaults
		origin = (typeof origin !== 'string' ? ['canvas'] : origin.match(/\bcenter\b|\bcanvas\b|\bdefault\b/i) || ['canvas'] )[0].toLowerCase();
		lineColorHex = typeof(lineColorHex) === 'string' ? lineColorHex : "#8FD8D8";
		groupLineColorHex = typeof(groupLineColorHex) === 'string' ? groupLineColorHex : "#ff00ff";
		centerLineColorHex = typeof(centerLineColorHex) === 'string' ? centerLineColorHex : "#F5F5F5";
		hGridLineSpace = typeof(hGridLineSpace) === 'number' ? hGridLineSpace : 25;
		vGridLineSpace = typeof(vGridLineSpace) === 'number' ? hGridLineSpace : 25;
		// Returning this
		var gridLines = new createjs.Shape();
		var drawLine, 
		drawColor, 
		middle,
		drawRowX,
		isFirstGridLine, 
		canvasCenterY = this.stage.canvas.height / 2,
		canvasCenterX = this.stage.canvas.width / 2,
		hLineX = 0, 
		vLineY = 0,
		linesPerGroup = 4,
		gridLineCounter = 0,
		majTick = false,
		drawHLine = function(color, row)
		{
			gridLines.graphics.setStrokeStyle(1);
			gridLines.graphics.beginStroke(color);
			gridLines.graphics.moveTo(0, row);
			gridLines.graphics.lineTo(this.stage.canvas.width, row);
			gridLines.graphics.endStroke();
			gridLines.graphics.closePath();
		},
		drawVLine = function(color, col)
		{
			gridLines.graphics.setStrokeStyle(1);
			gridLines.graphics.beginStroke(color);
			gridLines.graphics.moveTo(col, 0);
			gridLines.graphics.lineTo(col, stage.canvas.height);
			gridLines.graphics.endStroke();
		};
		if (origin == "center")
			{
				hLineX -= this.stage.canvas.height/2 % hGridLineSpace;
			}
		gridLineCounter = 0;
		isFirstGridLine = hLineX != 0;
		while (hLineX < this.stage.canvas.height)
		{
			hLineX += hGridLineSpace;
			gridLineCounter ++;
			if ((isFirstGridLine ) || ( gridLineCounter % linesPerGroup == 0))
			{ 
				isFirstGridLine = false;
				gridLineCounter = 0;
				drawColor = groupLineColorHex;
			}
			else
			{
				drawColor = lineColorHex;
			}
			if (hLineX != canvasCenterY && hLineX != this.stage.canvas.height)
			{
				drawHLine(drawColor, hLineX);
			}
		}
		if (origin == "center")
		{
			vLineY -= this.stage.canvas.height/2 % vGridLineSpace;
		}
		gridLineCounter = 0;
		isFirstGridLine = vLineY != 0;
		while (vLineY < stage.canvas.width)
		{
			vLineY += vGridLineSpace;
			gridLineCounter ++;
			if ((isFirstGridLine ) || (gridLineCounter % linesPerGroup == 0))
			{ 
				isFirstGridLine = false;
				gridLineCounter = 0;
				drawColor = groupLineColorHex;
			}
			else
			{
				drawColor = lineColorHex;
			}
			if (vLineY != canvasCenterX && vLineY != this.stage.canvas.width)
			{
				drawVLine(drawColor, vLineY)
			}
		}
		drawHLine(centerLineColorHex, canvasCenterY);
		drawVLine(centerLineColorHex, canvasCenterX);
		return gridLines;
	}